/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSYx527DRIVER_H
#define CAENSYx527DRIVER_H

#include <Driver.h>

#include "CAENHVWrapper.h"

namespace caen_syx527 {

/*!
 * \class CAENSYx527Driver
 * \brief Main class for the CAENSYx527Driver device driver
 *
 * \par
 * Class for CAENSYx527Driver driver. Implements DeviceDriver methods.
 * \par
 * The CAENSYx527Driver device manages the global functionality of the CAEN SYx527 VME Power Supply Card.
 */

class CAENSYx527Driver : public virtual DeviceDriver{

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENSYx527Driver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENSYx527Driver();

	/*!
	 * \brief Method called for executing a command
	 *
	 * \param[in] command the command to apply on the controller
	 */
	void execute(const string& aCommand);

	/**
	 * Update local value after a set property.
	 */
	virtual void refreshNSlotProperty(int32 value) throw (CannotSetValue);
	virtual void refreshNTotalChannelProperty(int32 value) throw (CannotSetValue);

	void readParamChannels();

	void writeParam(int iChannel,string Param,float value);

	void powerOn(int iChannel);

	void powerOff(int iChannel);

	Property<std::string> modelcrate;
	Property<std::string> linktype;
	Property<std::string> address;

	Property<int32> nslot;
	DynamicProperty<int32> nchannelperslot;
	DynamicProperty<std::string> modelboard;
	DynamicProperty<std::string> descrboard;
	DynamicProperty<int32> serialboard;
	DynamicProperty<std::string> firmboard;

	Property<int32> ntotchannel;
	DynamicProperty<int32> islot;
	DynamicProperty<int32> ichannel;
	DynamicProperty<std::string> namechannel;
	DynamicProperty<float64> i0set;
	DynamicProperty<float64> v0set;
	DynamicProperty<float64> imon;
	DynamicProperty<float64> vmon;
	DynamicProperty<std::string> power;
	DynamicProperty<std::string> statuschannel;
	DynamicProperty<float64> rampup;
	DynamicProperty<float64> rampdown;

	CAENHV_SYSTEM_TYPE_t model;
	int sysHndl;

	bool locked;


};

}
#endif //CAENSYx527DRIVER_H
