/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PERFECTSTEREOELECDRIVER_H
#define PERFECTSTEREOELECDRIVER_H

#include "StereoElecState.h"

namespace stereo_elec {

class StereoElecDriver;

/**
 * Perfect implementation of the stereo electronics
 */
class PerfectStereoElecDriver: public StereoElecState {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	PerfectStereoElecDriver(StereoElecDriver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~PerfectStereoElecDriver();

	/**
	 * Perform a init.
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void start();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	virtual void config();

};

}
#endif //PERFECTSTEREOELECDRIVER_H
